==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectDiscipline.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectdiscipline_h
#define objectdiscipline_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_discipline {
  t_adms _adms;
  char* _name;
  int _name_isdefault : 1;
  p_nature _flow;
  int _flow_isdefault : 1;
  p_nature _potential;
  int _potential_isdefault : 1;
};
#include <admsObject/objectNature.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_discipline_getuid (p_discipline mydiscipline);
win32_interface gboolean adms_discipline_cmp (p_discipline mydiscipline,p_discipline refdiscipline);
win32_interface p_discipline adms_discipline_new_1 (char* myname);
#define adms_discipline_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_discipline_free(item)\
{\
  free(item->_name);\
  free(item);\
}
win32_interface p_adms adms_discipline_new_impl (p_adms arguments[]);
win32_interface p_discipline adms_discipline_impl (void* member);
#define adms_discipline(member) ((p_discipline) (member))
#define adms_discipline_new adms_discipline_new_1
#define adms_discipline_isdefault_name(discipline) (adms_discipline(discipline)->_name_isdefault)
#define adms_discipline_valueof_name(discipline) (adms_discipline(discipline)->_name)
#define adms_discipline_isdefault_flow(discipline) (adms_discipline(discipline)->_flow_isdefault)
#define adms_discipline_valueof_flow(discipline) (adms_discipline(discipline)->_flow)
#define adms_discipline_isdefault_potential(discipline) (adms_discipline(discipline)->_potential_isdefault)
#define adms_discipline_valueof_potential(discipline) (adms_discipline(discipline)->_potential)
#define adms_discipline_valueof_adms(discipline) ((p_adms)discipline)
#define adms_discipline_valueto_name(a,b) ((p_discipline)a)->_name=(b)
win32_interface void adms_discipline_valueto_name_impl (p_discipline mydiscipline,char* _name);
#define adms_discipline_valueto_flow(a,b) ((p_discipline)a)->_flow=(b)
win32_interface void adms_discipline_valueto_flow_impl (p_discipline mydiscipline,p_nature _flow);
#define adms_discipline_valueto_potential(a,b) ((p_discipline)a)->_potential=(b)
win32_interface void adms_discipline_valueto_potential_impl (p_discipline mydiscipline,p_nature _potential);
#endif /* objectdiscipline_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectDiscipline.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectdiscipline_h
#define objectdiscipline_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_discipline {
  t_adms _adms;
  p_quark _name;
  int _name_isdefault : 1;
  p_nature _flow;
  int _flow_isdefault : 1;
  p_nature _potential;
  int _potential_isdefault : 1;
};
#include <admsObject/objectQuark.h>
#include <admsObject/objectNature.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_discipline_uid (p_discipline mydiscipline);
win32_interface int adms_discipline_cmp (p_discipline mydiscipline,p_discipline refdiscipline);
win32_interface p_discipline adms_discipline_new(p_quark myname);
win32_interface p_adms adms_discipline_new_impl (p_adms arguments[]);
#define adms_discipline(member) ((p_discipline) (member))
#define adms_discipline_isdefault_name(discipline) (adms_discipline(discipline)->_name_isdefault)
#define adms_discipline_valueof_name(discipline) (adms_discipline(discipline)->_name)
#define adms_discipline_isdefault_flow(discipline) (adms_discipline(discipline)->_flow_isdefault)
#define adms_discipline_valueof_flow(discipline) (adms_discipline(discipline)->_flow)
#define adms_discipline_isdefault_potential(discipline) (adms_discipline(discipline)->_potential_isdefault)
#define adms_discipline_valueof_potential(discipline) (adms_discipline(discipline)->_potential)
#define adms_discipline_valueof_adms(discipline) ((p_adms)discipline)
win32_interface inline void adms_discipline_valueto_name (p_discipline mydiscipline,p_quark _name);
win32_interface inline void adms_discipline_valueto_flow (p_discipline mydiscipline,p_nature _flow);
win32_interface inline void adms_discipline_valueto_potential (p_discipline mydiscipline,p_nature _potential);
win32_interface inline void adms_discipline_free(p_discipline mydiscipline);
#endif /* objectdiscipline_h */
